@@ -50,15 +50,17 @@ from .cho import cho_solve
 from .det import plogdet
 from .diag import sum2diag, trace2
 from .dot import ddot, dotd
+from .lstsq import lstsq
 from .lu import lu_slogdet, lu_solve
 from .property import check_definite_positiveness, check_symmetry
 from .qs import economic_qs, economic_qs_linear
-from .solve import solve, rsolve
+from .solve import rsolve, solve
 from .svd import economic_svd
 from .tri import stl
-from .lstsq import lstsq
 
-__all__ = ['cho_solve', 'sum2diag', 'trace2', 'ddot', 'dotd', 'lu_slogdet',
-           'lu_solve', 'check_definite_positiveness', 'check_symmetry',
-           'economic_qs', 'economic_qs_linear', 'solve', 'rsolve', 'economic_svd',
-           'stl', 'lstsq', 'plogdet']
+__all__ = [
+    'cho_solve', 'sum2diag', 'trace2', 'ddot', 'dotd', 'lu_slogdet',
+    'lu_solve', 'check_definite_positiveness', 'check_symmetry', 'economic_qs',
+    'economic_qs_linear', 'solve', 'rsolve', 'economic_svd', 'stl', 'lstsq',
+    'plogdet'
+]
